import logging
import logging.config

from fastapi import FastAPI
from fastapi.middleware.cors import CORSMiddleware
from logmiddleware import RouterLoggingMiddleware, logging_config

from src.api.config import API_DEBUG
from src.api.db import Base, engine
from src.api.routes import flights, health

logging.config.dictConfig(logging_config)
logger = logging.getLogger(__name__)

Base.metadata.create_all(bind=engine)


app = FastAPI(title="Flights Information API")
app.include_router(flights.router, prefix="/flights")
app.include_router(health.router, prefix="/health")
app.add_middleware(
    CORSMiddleware,
    allow_origins=[
        "https://fids.slc.ar",
        "https://airport.fids.slc.ar",
        "http://localhost:8080",
        "http://localhost:8081",
        "http://localhost:3000",
    ],
    allow_credentials=True,
    allow_methods=["POST", "GET", "PUT", "DELETE", "OPTIONS"],
    allow_headers=["*"],
)
app.add_middleware(RouterLoggingMiddleware, logger=logger, api_debug=API_DEBUG)
